package geniusweb.inform;

import java.util.Collections;
import java.util.List;
import java.util.Map;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;

import geniusweb.actions.PartyId;
import geniusweb.issuevalue.Bid;

/**
 * Informs a party that it's time to do voting.
 */
public class Voting implements Inform {

	private final List<Bid> bids;
	private final Map<PartyId, Integer> powers;

	@JsonCreator
	public Voting(@JsonProperty("bids") List<Bid> bids,
			@JsonProperty("powers") Map<PartyId, Integer> powers) {
		this.bids = bids;
		this.powers = powers;
	}

	/**
	 * @return list of bids to be voted on
	 */
	public List<Bid> getBids() {
		return Collections.unmodifiableList(bids);
	}

	/**
	 * 
	 * @return map with the power of each party in the negotiation. This map may
	 *         contain parties that are already finished, eg they reached an
	 *         agreement or walked away.
	 */
	public Map<PartyId, Integer> getPowers() {
		return Collections.unmodifiableMap(powers);
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((bids == null) ? 0 : bids.hashCode());
		result = prime * result + ((powers == null) ? 0 : powers.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		Voting other = (Voting) obj;
		if (bids == null) {
			if (other.bids != null)
				return false;
		} else if (!bids.equals(other.bids))
			return false;
		if (powers == null) {
			if (other.powers != null)
				return false;
		} else if (!powers.equals(other.powers))
			return false;
		return true;
	}

	@Override
	public String toString() {
		return "Voting[" + bids + "," + powers + "]";
	}

}
